@@ -14,41 +14,47 @@ import org.openstreetmap.gui.jmapviewer.JMapViewer;
  * @see JMapViewer#addMapMarker(MapMarker)
  * @see JMapViewer#getMapMarkerList()
  */
-public interface MapMarker extends MapObject, ICoordinate{
+public interface MapMarker extends MapObject, ICoordinate {
 
-    public static enum STYLE {FIXED, VARIABLE}
+    enum STYLE {
+        FIXED,
+        VARIABLE
+    }
 
     /**
      * @return Latitude and Longitude of the map marker position
      */
-    public Coordinate getCoordinate();
+    Coordinate getCoordinate();
+
     /**
      * @return Latitude of the map marker position
      */
-    public double getLat();
+    @Override
+    double getLat();
 
     /**
      * @return Longitude of the map marker position
      */
-    public double getLon();
+    @Override
+    double getLon();
 
     /**
      * @return Radius of the map marker position
      */
-    public double getRadius();
+    double getRadius();
 
     /**
      * @return Style of the map marker
      */
-    public STYLE getMarkerStyle();
+    STYLE getMarkerStyle();
 
     /**
      * Paints the map marker on the map. The <code>position</code> specifies the
      * coordinates within <code>g</code>
      *
-     * @param g
-     * @param position
-     * @param radio
+     * @param g graphics
+     * @param position coordinates
+     * @param radius radius
      */
-    public void paint(Graphics g, Point position, int radio);
+    void paint(Graphics g, Point position, int radius);
 }
